.. ctcsound7 documentation master file, created by
   sphinx-quickstart on Wed Nov 20 10:53:34 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ctcsound7's documentation!
=====================================

Python bindings for Csound

This package can be used with any version of csound >= 6.18.
Csound 7 is explicitely supported. It is for the most part
compatible with both version of csound without modifications.
At runtime the correct API is imported based on csound's
version.


------------


.. toctree:: ctcsound7
	:maxdepth: 1

	introduction
	csound7
	csound6
